==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/es/issues.php <==
<?php
regGS("Issue List", "");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "Nombre");
regGS("Front Page Template<BR><SMALL>(click to change)</SMALL>", "Plantilla de Portada");
regGS("Single Article Template<BR><SMALL>(click to change)</SMALL>", "Plantilla de Artículos Individuales");
regGS("Published<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Publicado");
regGS("Delete issue $1", "Borrar edición $1");
regGS("Change issue status", "Cambiar estatus de edición ");
regGS("You do not have the right to change issues.", "No tiene derecho a cambiar estatus de edición");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "Esta seguro que desea cambiar el status de la edición $1 de $2 a $3?");
regGS("Changing issue status", "Cambiando estatus de edición");
regGS("Status of the issue $1 has been changed from $2 to $3", "Estatus de edición $1 ha sido cambiado de $2 a $3");
regGS("Status of the issue $1 could not be changed.", "Estatus de edición $1 no pudo ser cambiado");
regGS("Add new translation", "Agregar nueva traducción");
regGS("You do not have the right to add issues.", "No tiene derecho a agregar ediciones");
regGS("The issue $1 has been successfuly added.", "La edición $1 ha sido agregada con éxito");
regGS("The issue could not be added.", "La edición no puedo ser agregada");
regGS("Please check if another issue with the same number/language does not already exist.", "Favor revise si otra edición con el mismo número/idioma no existe ya");
regGS("Change issue details", "Cambian detalles de edición");
regGS("You do not have the right to change issue details.", "No tiene derechos para cambiar detalles de edición");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Fecha de Publicación");
regGS("Updating issue", "Actualizando edición");
regGS("Changing issue's details", "Cambiando detalles de edición");
regGS("The issue $1 has been successfuly changed.", "La edición $1 ha sido cambiada con éxito");
regGS("The issue could not be changed.", "La edición no pudo ser cambiada");
regGS("Issue $1 updated in publication $2", "Edición $1 actualizada en publicación $2");
regGS("You do not have the right to delete issues.", "No tiene derechos para borrar ediciones");
regGS("Are you sure you want to delete the issue $1?", "¿Estas seguro que desea borrar la edición $1?");
regGS("Deleting issue", "Borrando edición");
regGS("Use the structure of the previous issue", "Usar la estructura de la edición previa");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "Copiar la estructura completa de todos los idiomas de la edición precia exceptuando el contenido");
regGS("You may modify it later if you wish.", "Puede modificarla luego si desea");
regGS("Create a new structure", "Crear una nueva estructura");
regGS("Create a complete new structure.", "Crear una nueva estructura completa");
regGS("You must define an issue type for each language and then sections for them.", "Debe definir un tipo edición para cada idioma y secciones para ella");
regGS("Copy previous issue", "Copiar edición previa");
regGS("No previous issue.", "Sin ediciones previas");
regGS("Copy structure from issue nr $1", "Copiar estructura de edición No. $1");
regGS("Copying previous issue", "Copiando edición previa");
regGS("Select the issue", "Seleccionar la edición");
regGS("New issue $1 from $2 in publication $3", "Nueva edición $1 de $2 en publicación $3");
regGS("Adding new issue", "Agregando nueva edición");
regGS("Preview issue", "Vista previa de edición");
regGS("This issue cannot be previewed. Please make sure it has a $1 template selected.", "La edición no puede ser pre-vista.  Favor asegurese de que tiene una plantilla de $1 seleccionada");
regGS("front page", "portada");
regGS("Changing issue template", "Cambiando plantilla de edición");
regGS("You do not have the right to change issue templates.", "No tiene derecho a cambiar plantillas de edición");
regGS("Changing issue template for front page", "Cambiando plantilla de edición para portada");
regGS("Changing issue template for single article", "Cambiando plantilla de edición para artículos individuales");
regGS("The template has been successfully changed.", "La plantilla ha sido cambiada con éxito");
regGS("Issue template for publication $1 changed to $2", "Plantilla de edición para publicación $1 cambió a $2");
regGS("Issue template for single articles from $1 changed to $2", "Plantilla de edición para artículos individuales $1 cambió a $1");
regGS("The template could not be changed.", "La platilla no pudo ser cambiada");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/es/issues.php <==
<?php 
regGS("Change issue status", "Modificar el estatus de la edición");
regGS("The values you are trying to set conflict with issue \"$1$2. $3 ($4)$5\".", "Los valores que intenta establecer tienen conflicto con la edición \"$1$2. $3 ($4)$5\".");
regGS("The number must be unique for each issue in this publication of the same language.", "Cada edición en esta publicación del mismo idioma debe tener un número único.");
regGS("The language and URL name must be unique for each issue in this publication.", "El idioma y el nombre del URL deben ser únicos para cada edición en esta publicación.");
regGS("Issue created.", "Se creo una nueva edición.");
regGS("Issue updated", "Se actualizó la edición.");
regGS("Could not save the changes to the issue.", "No fue posible almacenar los cambios a la edición.");
regGS("Unpublish on: $1", "Despublicar el:  $1");
regGS("There are $1 articles in this issue.", "Hay $1 artículos en esta edición");
regGS("The issue $1 has been deleted.", "Se ha eliminado la edición $1");
regGS("Schedule", "Calendarizar");
regGS("Publish on: $1", "Publicar el: $1");
regGS("Publish Date $1", "Fecha de publicación $1");
regGS("Deleted issue", "Edición eliminada");
regGS("Delete issue", "Eliminiar edición");
regGS("Click here to publish this issue", "Pinche aquí para publicar esta edición");
regGS("A total of $1 articles were deleted.", "Se eliminó un total de $1 artículos");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "Nombre");
regGS("Delete issue $1", "Borrar edición $1");
regGS("Publish articles", "Publicar artículos");
regGS("You do not have the right to change issues.", "No tiene derecho a cambiar estatus de edición");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "Esta seguro que desea cambiar el status de la edición $1 de $2 a $3?");
regGS("Add new translation", "Agregar nueva traducción");
regGS("You do not have the right to add issues.", "No tiene derecho a agregar ediciones");
regGS("The issue $1 has been successfuly added.", "La edición $1 ha sido agregada con éxito");
regGS("The issue could not be added.", "La edición no puedo ser agregada");
regGS("Change issue details", "Cambian detalles de edición");
regGS("You do not have the right to change issue details.", "No tiene derechos para cambiar detalles de edición");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Fecha de Publicación");
regGS("Front Page Template", "Plantilla de portada");
regGS("Issue $1 updated in publication $2", "Edición $1 actualizada en publicación $2");
regGS("You do not have the right to delete issues.", "No tiene derechos para borrar ediciones");
regGS("Are you sure you want to delete the issue $1?", "¿Estas seguro que desea borrar la edición $1?");
regGS("Use the structure of the previous issue", "Usar la estructura de la edición previa");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "Copiar la estructura completa de todos los idiomas de la edición precia exceptuando el contenido");
regGS("You may modify it later if you wish.", "Puede modificarla luego si desea");
regGS("Create a new structure", "Crear una nueva estructura");
regGS("Create a complete new structure.", "Crear una nueva estructura completa");
regGS("You must define an issue type for each language and then sections for them.", "Debe definir un tipo edición para cada idioma y secciones para ella");
regGS("Copy previous issue", "Copiar edición previa");
regGS("No previous issue.", "Sin ediciones previas");
regGS("Copy structure from issue number $1", "Copiar estructura de edición No. $1");
regGS("New issue $1 from $2 in publication $3", "Nueva edición $1 de $2 en publicación $3");
regGS("Delete entry", "Eliminar registro");
regGS("Issue Publishing Schedule", "Horario de publicación de ediciones");
regGS("Invalid Input: $1", "Registro inválido:  $1");
regGS("Issue Number", "Edición número");
regGS("Go To Sections", "Ir a secciones");
regGS("There was an error reading the language parameter.", "Hubo un error en la lectura del parámetro de idioma.");
regGS("There was an error reading the publication parameter.", "Hubo un error en la lectura del parámetro de publicación.");
regGS("There was an error reading the issue parameter.", "Hubo un error en la lectura del parámetro de edición.");
regGS("There was an error scheduling the $1 action on $2", "Hubo un error en la programación de la acción $1 para el $2");
regGS("The action scheduled on $1 could not be deleted.", "No se pudo eliminar la acción $1.");
regGS("Front Page Template<BR><SMALL>(click to change)</SMALL>", "Plantilla de Portada");
regGS("Single Article Template<BR><SMALL>(click to change)</SMALL>", "Plantilla de Artículos Individuales");
regGS("Changing issue status", "Cambiando estatus de edición");
regGS("Status of the issue $1 has been changed from $2 to $3", "Estatus de edición $1 ha sido cambiado de $2 a $3");
regGS("Status of the issue $1 could not be changed.", "Estatus de edición $1 no pudo ser cambiado");
regGS("Updating issue", "Actualizando edición");
regGS("Changing issue's details", "Cambiando detalles de edición");
regGS("The issue $1 has been successfuly changed.", "La edición $1 ha sido cambiada con éxito");
regGS("The issue could not be changed.", "La edición no pudo ser cambiada");
regGS("Preview issue", "Vista previa de edición");
regGS("This issue cannot be previewed. Please make sure it has a $1 template selected.", "La edición no puede ser pre-vista.  Favor asegurese de que tiene una plantilla de $1 seleccionada");
regGS("front page", "portada");
regGS("Changing issue template", "Cambiando plantilla de edición");
regGS("You do not have the right to change issue templates.", "No tiene derecho a cambiar plantillas de edición");
regGS("Changing issue template for front page", "Cambiando plantilla de edición para portada");
regGS("Changing issue template for single article", "Cambiando plantilla de edición para artículos individuales");
regGS("The template has been successfully changed.", "La plantilla ha sido cambiada con éxito");
regGS("Issue template for publication $1 changed to $2", "Plantilla de edición para publicación $1 cambió a $2");
regGS("Issue template for single articles from $1 changed to $2", "Plantilla de edición para artículos individuales $1 cambió a $1");
regGS("The template could not be changed.", "La platilla no pudo ser cambiada");
?>
